@@ -1,19 +1,16 @@
 import logging
-import os
 import tempfile
 from mappyfile import cli
 import pytest
 
 
 def test_get_mapfiles():
-
     tf = tempfile.NamedTemporaryFile(suffix=".map")
     print(tf.name)
 
     mapfiles = [tf.name]
     found_mapfiles = cli.get_mapfiles(mapfiles)
     print(found_mapfiles)
-    os.remove(tf.name)
 
 
 def run_tests():
