@@ -8,19 +8,15 @@ from mappyfile.transformer import MapfileToDict
 from mappyfile.pprint import PrettyPrinter
 from subprocess import Popen, PIPE, STDOUT
 import pytest
+from urllib.parse import urlsplit
 
-try:
-    from urllib.parse import urlsplit
-except ImportError:
-    from urlparse import urlsplit
 
 DLL_LOCATION = r"C:\MapServer\bin"
 
 
 def create_image(name, mapfile, output_folder, format="png"):
-
     out_map = os.path.join(output_folder, "%s.map" % name)
-    mappyfile.write(mapfile, out_map)
+    mappyfile.save(mapfile, out_map)
 
     out_img = os.path.join(output_folder, name)
 
@@ -28,7 +24,6 @@ def create_image(name, mapfile, output_folder, format="png"):
 
 
 def _create_image_from_map(map_file, out_img, format):
-
     out_img += ".%s" % format
 
     params = [
@@ -41,19 +36,23 @@ def _create_image_from_map(map_file, out_img, format):
         out_img,
         "-s",
         256,
-        256]  # ,  # "-e", "0 0 5 5"
+        256,
+    ]  # ,  # "-e", "0 0 5 5"
     params = [str(p) for p in params]
     logging.info(" ".join(params))
 
-    os.environ['PATH'] = DLL_LOCATION + ';' + os.environ['PATH']
+    os.environ["PATH"] = DLL_LOCATION + ";" + os.environ["PATH"]
 
     p = Popen(params, stdout=PIPE, stderr=STDOUT)
 
     errors = []
 
+    if p.stdout is None:
+        raise IOError("Cannot create stdout")
+
     with p.stdout:
-        for line in iter(p.stdout.readline, b''):
-            errors.append(line)
+        for line in iter(p.stdout.readline, b""):
+            errors.append(str(line))
 
     p.wait()  # wait for the subprocess to exit
 
@@ -62,7 +61,8 @@ def _create_image_from_map(map_file, out_img, format):
         return None
     else:
         logging.info("Created %s", out_img)
-        os.startfile(out_img)
+        # os.startfile is only available on Windows
+        # os.startfile(out_img)
 
     return out_img
 
@@ -150,7 +150,7 @@ def test_config_validation():
     END
     """
     errors = validate(s)
-    assert(len(errors) == 0)
+    assert len(errors) == 0
 
 
 def test_color_validation():
@@ -160,7 +160,7 @@ def test_color_validation():
     END
     """
     errors = validate(s)
-    assert(len(errors) == 0)
+    assert len(errors) == 0
 
 
 def test_color_validation_fail():
@@ -170,7 +170,7 @@ def test_color_validation_fail():
     END
     """
     errors = validate(s)
-    assert(len(errors) == 1)
+    assert len(errors) == 1
 
 
 def test_hexcolor_validation():
@@ -180,7 +180,7 @@ def test_hexcolor_validation():
     END
     """
     errors = validate(s)
-    assert(len(errors) == 0)
+    assert len(errors) == 0
 
 
 def test_hexcolor_validation_fail():
@@ -190,7 +190,7 @@ def test_hexcolor_validation_fail():
     END
     """
     errors = validate(s)
-    assert(len(errors) == 1)
+    assert len(errors) == 1
 
 
 def test_hexcolor_validation_translucence():
@@ -211,7 +211,7 @@ def test_hexcolor_validation_translucence():
     END
     """
     errors = validate(s)
-    assert(len(errors) == 0)
+    assert len(errors) == 0
 
 
 def test_nested_validation():
@@ -225,11 +225,10 @@ def test_nested_validation():
     """
     errors = validate(s)
     print(errors)
-    assert(len(errors) == 1)
+    assert len(errors) == 1
 
 
 def test_lowercase():
-
     s = """
     MAP
         NAME 'blah'
@@ -276,7 +275,7 @@ def test_lowercase():
     print(json.dumps(d, indent=4))
     errors = validate(s)
     print(errors)
-    assert(len(errors) == 0)
+    assert len(errors) == 0
     # deepcopy crashes on (u'config', OrderedDict([('ON_MISSING_DATA', Token(NAME, 'FAIL'))]))
 
 
@@ -284,13 +283,13 @@ def test_ref_path():
     url = "file:////home/user/mappyfile/mappyfile/schemas/"
     scheme, netloc, path, query, fragment = urlsplit(url)
     print(scheme, netloc, path, query, fragment)
-    assert(scheme == "file")
+    assert scheme == "file"
 
     url = "file:///D:/GitHub/mappyfile/mappyfile/schemas/"
 
     scheme, netloc, path, query, fragment = urlsplit(url)
     print(scheme, netloc, path, query, fragment)
-    assert(scheme == "file")
+    assert scheme == "file"
 
 
 def test_add_comments():
@@ -327,14 +326,17 @@ def test_deref():
     schema_name = "cluster"
     validator = v.get_schema_validator(schema_name)
     jsn_schema = validator.schema
+    assert isinstance(jsn_schema, dict)
 
     print(json.dumps(jsn_schema, indent=4))
     print(jsn_schema["properties"]["filter"])
-    assert(list(jsn_schema["properties"]["filter"].keys())[0] == "$ref")
+    assert list(jsn_schema["properties"]["filter"].keys())[0] == "$ref"
     deref_schema = v.get_expanded_schema(schema_name)
     print(json.dumps(deref_schema, indent=4))
     print(deref_schema["properties"]["filter"])
-    assert(list(deref_schema["properties"]["filter"].keys())[0] == "anyOf")
+    assert list(deref_schema["properties"]["filter"].keys())[0] == "anyOf"
+    print(json.dumps(deref_schema["properties"]["filter"]))
+    assert json.dumps(deref_schema["properties"]["filter"]) is not None
 
 
 def test_cached_schema():
@@ -345,12 +347,14 @@ def test_cached_schema():
     schema_name = "cluster"
     validator = v.get_schema_validator(schema_name)
     jsn_schema = validator.schema
-    assert(list(jsn_schema["properties"]["filter"].keys())[0] == "$ref")
+    assert isinstance(jsn_schema, dict)
+    assert list(jsn_schema["properties"]["filter"].keys())[0] == "$ref"
 
     # get the schame again
     validator = v.get_schema_validator(schema_name)
     jsn_schema = validator.schema
-    assert(list(jsn_schema["properties"]["filter"].keys())[0] == "$ref")
+    assert isinstance(jsn_schema, dict)
+    assert list(jsn_schema["properties"]["filter"].keys())[0] == "$ref"
 
 
 def test_cached_expanded_schema():
@@ -361,11 +365,11 @@ def test_cached_expanded_schema():
     schema_name = "cluster"
 
     deref_schema = v.get_expanded_schema(schema_name)
-    assert(list(deref_schema["properties"]["filter"].keys())[0] == "anyOf")
+    assert list(deref_schema["properties"]["filter"].keys())[0] == "anyOf"
 
     # get the schame again
     deref_schema = v.get_expanded_schema(schema_name)
-    assert(list(deref_schema["properties"]["filter"].keys())[0] == "anyOf")
+    assert list(deref_schema["properties"]["filter"].keys())[0] == "anyOf"
 
 
 def test_extra_property_validation():
@@ -385,11 +389,10 @@ def test_extra_property_validation():
     v = Validator()
     errors = v.validate(d, add_comments=True)
     print(errors)
-    assert(len(errors) == 1)
+    assert len(errors) == 1
 
 
 def test_double_error():
-
     s = """MAP
     NAME "sample"
     STATUS ON
@@ -420,12 +423,11 @@ END"""
     # print(errors)
     for e in errors:
         print(e)
-    assert(len(errors) == 2)
+    assert len(errors) == 2
     print(mappyfile.dumps(d))
 
 
 def test_line_position_mutlilines():
-
     s = """MAP
     NAME "sample"
     LAYER
@@ -449,10 +451,10 @@ END"""
     # print(errors)
     for e in errors:
         print(e)
-    assert(len(errors) == 1)
+    assert len(errors) == 1
     err = errors[0]
-    assert(err["line"] == 9)
-    assert(err["column"] == 9)
+    assert err["line"] == 9
+    assert err["column"] == 9
     print(mappyfile.dumps(d))
 
 
@@ -477,8 +479,7 @@ def test_root_position():
 
 
 def test_cluster_validation():
-
-    s = u"""
+    s = """
     MAP
         LAYER
             TYPE POINT
@@ -499,8 +500,7 @@ def test_cluster_validation():
 
 
 def test_cluster_validation_fail():
-
-    s = u"""
+    s = """
     MAP
         LAYER
             TYPE POINT
@@ -520,7 +520,6 @@ def test_cluster_validation_fail():
 
 
 def test_version_warnings():
-
     s = """MAP
     NAME "sample"
     LAYER
@@ -541,32 +540,27 @@ END"""
 
 
 def test_keyword_versioning():
-
-    properties = {
-  "type": "object",
-  "properties": {
-    "__type__": {
-      "enum": ["label"]
-    },
-    "align": {
-      "oneOf": [
-        {
-          "type": "string",
-          "enum": ["left", "center", "right"],
-          "additionalProperties": False
+    properties: dict = {
+        "type": "object",
+        "properties": {
+            "__type__": {"enum": ["label"]},
+            "align": {
+                "oneOf": [
+                    {
+                        "type": "string",
+                        "enum": ["left", "center", "right"],
+                        "additionalProperties": False,
+                    },
+                    {
+                        "type": "string",
+                        "pattern": "^\\[(.*?)\\]$",
+                        "description": "attribute",
+                    },
+                ],
+                "metadata": {"minVersion": 5.4},
+            },
         },
-        {
-          "type": "string",
-          "pattern": "^\\[(.*?)\\]$",
-          "description": "attribute"
-        }
-      ],
-      "metadata": {
-        "minVersion": 5.4
-      }
     }
-  }
-}
 
     v = Validator()
     assert "align" in properties["properties"].keys()
@@ -576,22 +570,17 @@ def test_keyword_versioning():
 
 
 def test_property_versioning():
-
     properties = {
-      "force": {
-      "oneOf": [
-        {"type": "boolean"},
-        {
-          "enum": ["group"],
-          "metadata": {
-            "minVersion": 6.2
-          }
-        }]
-      }
+        "force": {
+            "oneOf": [
+                {"type": "boolean"},
+                {"enum": ["group"], "metadata": {"minVersion": 6.2}},
+            ]
+        }
     }
 
     v = Validator()
-    assert "enum" in properties["force"]["oneOf"][1].keys()
+    assert "enum" in properties["force"]["oneOf"][1].keys()  # type: ignore
     assert len(properties["force"]["oneOf"]) == 2
     properties = v.get_versioned_properties(properties, 6.0)
     print(json.dumps(properties, indent=4))
@@ -627,13 +616,79 @@ END"""
 
 
 def test_get_versioned_schema():
-
     validator = Validator()
     jsn = validator.get_versioned_schema(7.6)
     # print(json.dumps(jsn, indent=4))
     assert "defresolution" in jsn["properties"].keys()
 
 
+def test_get_outputformat_schema():
+    validator = Validator()
+    schema_name = "outputformat.json"
+    jsn = validator.get_json_from_file(schema_name)
+    # print(json.dumps(jsn, indent=4))
+    assert jsn["properties"]["transparent"]["oneOf"][1]["$ref"] == "onoff.json"
+    expanded_schema = validator.get_expanded_schema(schema_name)
+    # print(json.dumps(expanded_schema, indent=4))
+    assert expanded_schema["properties"]["transparent"]["oneOf"][1]["enum"] == [
+        "on",
+        "off",
+    ]
+
+
+def test_get_full_versioned_schema():
+    validator = Validator()
+    versioned_schema = validator.get_versioned_schema(8.2, "map")
+    # print(json.dumps(versioned_schema, indent=4))
+    output_formats = versioned_schema["properties"]["outputformats"]["items"]
+    # print(json.dumps(output_formats, indent=4))
+    # print(json.dumps(versioned_schema, indent=4))
+    assert output_formats["properties"]["transparent"]["oneOf"][1]["enum"] == [
+        "on",
+        "off",
+    ]
+
+
+def test_fallback_validation():
+    s = """
+    MAP
+        LAYER
+            TYPE POLYGON
+            CLASS
+                FALLBACK TRUE
+            END
+        END
+    END
+    """
+    errors = validate(s)
+    print(errors)
+    assert len(errors) == 0
+
+    d = mappyfile.loads(s, include_position=False)
+    v = Validator()
+    errors = v.validate(d, add_comments=True, version=8.4)
+    print(errors)
+    assert len(errors) == 1
+
+
+def test_fallback_old_version_validation():
+    s = """
+    MAP
+        LAYER
+            TYPE POLYGON
+            CLASS
+                FALLBACK TRUE
+            END
+        END
+    END
+    """
+    d = mappyfile.loads(s, include_position=False)
+    v = Validator()
+    errors = v.validate(d, add_comments=True, version=8.4)
+    print(errors)
+    assert len(errors) == 1
+
+
 def run_tests():
     pytest.main(["tests/test_validation.py"])
 
@@ -641,5 +696,8 @@ def run_tests():
 if __name__ == "__main__":
     logging.basicConfig(level=logging.INFO)
     # run_tests()
-    test_object_versioning()
+    # test_double_error()
+    # test_deref()
+    # test_get_outputformat_schema()
+    test_fallback_validation()
     print("Done!")
